@@ -1,6 +1,6 @@
 from opentorsion.disk_element import Disk
 from opentorsion.shaft_element import Shaft
 from opentorsion.gear_element import Gear
-from opentorsion.assembly import Rotor
+from opentorsion.assembly import Assembly
 from opentorsion.errors import DOF_mismatch_error
 from opentorsion.plots import Plots
